.. _Regression Tree Graph:

Regression Tree Viewer
======================

.. image:: ../../../../Orange/OrangeWidgets/Regression/icons/RegressionTreeGraph.svg

Regression Tree Graph

Signals
-------

Inputs:
   - Examples (ExampleTable)
      A table with training examples


Outputs:
   - Regression Tree
      Trained classifier (a subtype of Classifier)


Description
-----------

This widget shows a regression tree. It is quite similar to the one for
classification tree, so please see the documentation for
:ref:`Classification Tree Graph`.
